@@ -43,7 +43,7 @@ enum {
   TT_POINT_TYPE = 3001,
   TT_POINT_SUBTYPE = 3002,
   TT_POINT_STATION = 3003,
-  TT_POINT_EXTEND = 3004,
+  TT_POINT_FROM = 3004,
   TT_POINT_ORIENT = 3005,
   TT_POINT_XSIZE = 3006,
   TT_POINT_YSIZE = 3007,
@@ -52,6 +52,8 @@ enum {
   TT_POINT_VALUE = 3010,
   TT_POINT_TEXT = 3011,
   TT_POINT_SCRAP = 3012,
+  TT_POINT_DIST = 3013,
+  TT_POINT_EXPLORED = 3014,
 };
 
 
@@ -61,12 +63,15 @@ enum {
  
 static const thstok thtt_point_opt[] = {
   {"align", TT_POINT_ALIGN},
-  {"extend", TT_POINT_EXTEND},
+  {"dist", TT_POINT_DIST},
+  {"explored", TT_POINT_EXPLORED},
+  {"from", TT_POINT_FROM},
   {"name", TT_POINT_STATION},
   {"orient", TT_POINT_ORIENT},
   {"orientation", TT_POINT_ORIENT},
   {"scrap", TT_POINT_SCRAP},
   {"size", TT_POINT_SIZE},
+  {"station", TT_POINT_STATION},
   {"subtype", TT_POINT_SUBTYPE},
   {"text", TT_POINT_TEXT},
   {"value", TT_POINT_VALUE},
@@ -106,6 +111,7 @@ enum {
   TT_POINT_TYPE_UNKNOWN,
 
 // specialne typy
+  TT_POINT_TYPE_U,
   TT_POINT_TYPE_STATION,
   TT_POINT_TYPE_SECTION,
   TT_POINT_TYPE_WATER_FLOW,
@@ -121,7 +127,10 @@ enum {
   TT_POINT_TYPE_AIR_DRAUGHT,
   TT_POINT_TYPE_ENTRANCE,
   TT_POINT_TYPE_GRADIENT,
+
   TT_POINT_TYPE_DIMENSIONS,
+  TT_POINT_TYPE_MAP_CONNECTION,
+  TT_POINT_TYPE_EXTRA,
   
 // vystroj
   TT_POINT_TYPE_NO_EQUIPMENT,
@@ -133,6 +142,7 @@ enum {
   TT_POINT_TYPE_BRIDGE,
   TT_POINT_TYPE_TRAVERSE,
   TT_POINT_TYPE_CAMP,
+  TT_POINT_TYPE_DIG,
 
 // ukoncenia chodby
   TT_POINT_TYPE_CONTINUATION,
@@ -140,6 +150,7 @@ enum {
   TT_POINT_TYPE_LOW_END,
   TT_POINT_TYPE_FLOWSTONE_CHOKE,
   TT_POINT_TYPE_BREAKDOWN_CHOKE,
+  TT_POINT_TYPE_CLAY_CHOKE,
 
 // vypln
   TT_POINT_TYPE_FLOWSTONE,
@@ -165,6 +176,10 @@ enum {
   TT_POINT_TYPE_SCALLOP,
   TT_POINT_TYPE_FLUTE,
   TT_POINT_TYPE_RAFT_CONE,
+  TT_POINT_TYPE_ICE_STALACTITE,
+  TT_POINT_TYPE_ICE_STALAGMITE,
+  TT_POINT_TYPE_ICE_PILLAR,
+
   
 // plosne vyplne
   TT_POINT_TYPE_BEDROCK,
@@ -178,6 +193,8 @@ enum {
   TT_POINT_TYPE_ICE,
   TT_POINT_TYPE_SNOW,
   TT_POINT_TYPE_GUANO,
+  TT_POINT_TYPE_CLAY_TREE,
+
 
 // ina vypln
   TT_POINT_TYPE_ARCHEO_MATERIAL,
@@ -206,14 +223,18 @@ static const thstok thtt_point_types[] = {
   {"camp",TT_POINT_TYPE_CAMP},
   {"cave-pearl",TT_POINT_TYPE_CAVE_PEARL},
   {"clay",TT_POINT_TYPE_CLAY},
+  {"clay-choke",TT_POINT_TYPE_CLAY_CHOKE},
+  {"clay-tree",TT_POINT_TYPE_CLAY_TREE},
   {"continuation",TT_POINT_TYPE_CONTINUATION},
   {"crystal",TT_POINT_TYPE_CRYSTAL},
   {"curtain",TT_POINT_TYPE_CURTAIN},
   {"date",TT_POINT_TYPE_DATE},
   {"debris",TT_POINT_TYPE_DEBRIS},
+  {"dig",TT_POINT_TYPE_DIG},
   {"dimensions",TT_POINT_TYPE_DIMENSIONS},
   {"disk",TT_POINT_TYPE_DISK},
   {"entrance",TT_POINT_TYPE_ENTRANCE},
+  {"extra",TT_POINT_TYPE_EXTRA},
   {"fixed-ladder",TT_POINT_TYPE_FIXED_LADDER},
   {"flowstone",TT_POINT_TYPE_FLOWSTONE},
   {"flowstone-choke",TT_POINT_TYPE_FLOWSTONE_CHOKE},
@@ -225,9 +246,13 @@ static const thstok thtt_point_types[] = {
   {"height",TT_POINT_TYPE_HEIGHT},
   {"helictite",TT_POINT_TYPE_HELICTITE},
   {"ice",TT_POINT_TYPE_ICE},
+  {"ice-pillar",TT_POINT_TYPE_ICE_PILLAR},
+  {"ice-stalactite",TT_POINT_TYPE_ICE_STALACTITE},
+  {"ice-stalagmite",TT_POINT_TYPE_ICE_STALAGMITE},
   {"karren",TT_POINT_TYPE_KARREN},
   {"label",TT_POINT_TYPE_LABEL},
   {"low-end",TT_POINT_TYPE_LOW_END},
+  {"map-connection",TT_POINT_TYPE_MAP_CONNECTION},
   {"moonmilk",TT_POINT_TYPE_MOONMILK},
   {"narrow-end",TT_POINT_TYPE_NARROW_END},
   {"no-equipment",TT_POINT_TYPE_NO_EQUIPMENT},
@@ -257,6 +282,7 @@ static const thstok thtt_point_types[] = {
   {"station-name", TT_POINT_TYPE_STATION_NAME},
   {"steps",TT_POINT_TYPE_STEPS},
   {"traverse",TT_POINT_TYPE_TRAVERSE},
+  {"u",TT_POINT_TYPE_U},
   {"vegetable-debris",TT_POINT_TYPE_VEGETABLE_DEBRIS},
   {"wall-calcite",TT_POINT_TYPE_WALL_CALCITE},
   {"water",TT_POINT_TYPE_WATER},
@@ -328,6 +354,9 @@ enum {
   TT_POINT_SUBTYPE_NEGATIVE,
   TT_POINT_SUBTYPE_BOTH,
   TT_POINT_SUBTYPE_UNSIGNED,
+  TT_POINT_SUBTYPE_WINTER,
+  TT_POINT_SUBTYPE_SUMMER,
+  TT_POINT_SUBTYPE_UNDEF,
 };
 
 
@@ -345,45 +374,15 @@ static const thstok thtt_point_subtypes[] = {
   {"paleo", TT_POINT_SUBTYPE_PALEO},
   {"permanent", TT_POINT_SUBTYPE_PERMANENT},
   {"positive", TT_POINT_SUBTYPE_POSITIVE},
+  {"summer", TT_POINT_SUBTYPE_SUMMER},
   {"temporary", TT_POINT_SUBTYPE_TEMP},
+  {"undefined", TT_POINT_SUBTYPE_UNDEF},
   {"unsigned", TT_POINT_SUBTYPE_UNSIGNED},
+  {"winter", TT_POINT_SUBTYPE_WINTER},
 	{NULL, TT_POINT_SUBTYPE_UNKNOWN},
 };
 
 
-/**
- * Extend options.
- */
- 
-enum {
-  TT_POINT_EXTEND_NONE = 0,
-  TT_POINT_EXTEND_STICKYON = 1,
-  TT_POINT_EXTEND_STICKYOFF = 2,
-  TT_POINT_EXTEND_STICKY = 3,
-  TT_POINT_EXTEND_LEFT = 4,
-  TT_POINT_EXTEND_RIGHT = 8,
-  TT_POINT_EXTEND_ROOT = 16,
-  TT_POINT_EXTEND_PREV = 17,
-};
-
-
-
-/**
- * Extend options parsing table.
- */
- 
-static const thstok thtt_point_extopt[] = {
-//  {"left", TT_POINT_EXTEND_LEFT},
-  {"prev", TT_POINT_EXTEND_PREV},
-  {"previous", TT_POINT_EXTEND_PREV},
-//  {"right", TT_POINT_EXTEND_RIGHT},
-//  {"root", TT_POINT_EXTEND_ROOT},
-//  {"sticky", TT_POINT_EXTEND_STICKY},
-	{NULL, TT_POINT_EXTEND_NONE},
-};
-
-
-
 /**
  * point class.
  */
@@ -399,16 +398,18 @@ class thpoint : public th2ddataobject {
     align;  ///< Point align.
   double orient, xsize, ysize;  ///<...
   
-  char * text;  ///< Point text.
+  const char * text;  ///< Point text.
     
   thdb2dpt * point;  ///< Point coordinates.
   
   class thdb2dcp * cpoint; ///< Control point.
   
   thobjectname station_name,  ///< Station name.
-    extend_name;  ///< Extend name.
-  thpoint * extend_point;  ///< Extend previous point.
+    from_name;  ///< Extend name.
+
   char extend_opts;  ///< Extend options.
+
+  virtual void start_insert();
     
   void parse_type(char * tstr);  ///< Parse point type.
 
@@ -416,12 +417,16 @@ class thpoint : public th2ddataobject {
   
   void parse_subtype(char * ststr);  ///< Parse point subtype.
   
-  void parse_extend(char * estr);  ///< Parse station extend.
+  void parse_from(char * estr);  ///< Parse station extend.
 
   void parse_text(char * ss);  ///< Parse point text.
 
+  void parse_explored(char * ss);  ///< Parse explored length.
+
   void parse_value(char * ss);  ///< Parse point value.
 
+  void check_extra();
+
   /**
    * Standard constructor.
    */
@@ -447,7 +452,7 @@ class thpoint : public th2ddataobject {
    * Return class name.
    */
    
-  virtual char * get_class_name() {return "thpoint";};
+  virtual const char * get_class_name() {return "thpoint";};
   
   
   /**
@@ -468,21 +473,21 @@ class thpoint : public th2ddataobject {
    * Return command name.
    */
    
-  virtual char * get_cmd_name();
+  virtual const char * get_cmd_name();
   
   
   /**
    * Return command end option.
    */
    
-  virtual char * get_cmd_end();
+  virtual const char * get_cmd_end();
   
   
   /**
    * Return option description.
    */
    
-  virtual thcmd_option_desc get_cmd_option_desc(char * opts);
+  virtual thcmd_option_desc get_cmd_option_desc(const char * opts);
   
   
   /**
