@@ -205,7 +205,7 @@ static const thstok thtt_symbol_special[] = {
             break; \
           }
 
-int thsymbolset__get_id(char * symclass, char * symbol)
+int thsymbolset__get_id(const char * symclass, const char * symbol)
 {
   int type, subtype, rv;
   char types[128], 
@@ -871,11 +871,6 @@ void thsymbolset::export_pdf(class thlayout * layout, FILE * mpf, unsigned & sfi
 
   legend_hpoint(SYMP_ENTRANCE,thT("point entrance",layout->lang));
 
-  insfig(SYML_ARROW,thT("line arrow",layout->lang));
-  this->export_mp_symbol_options(mpf, SYML_ARROW);
-  fprintf(mpf,"%s(((0.2,0.8) -- (0.8,0.2)) inscale,2)",thsymbolset__mp[SYML_ARROW]);
-  endfig;
-
   insfig(SYML_MAPCONNECTION,thT("line map-connection",layout->lang));
   this->export_mp_symbol_options(mpf, SYML_MAPCONNECTION);
   fprintf(mpf,"%s(((0.2,0.8) -- (0.8,0.2)) inscale)",thsymbolset__mp[SYML_MAPCONNECTION]);
@@ -1156,6 +1151,7 @@ void thsymbolset::export_pdf(class thlayout * layout, FILE * mpf, unsigned & sfi
   legend_area(SYMA_FLOWSTONE,thT("area flowstone",layout->lang));  
   legend_area(SYMA_MOONMILK,thT("area moonmilk",layout->lang));  
   legend_nocliparea(SYMA_BLOCKS,thT("area blocks",layout->lang));  
+  legend_nocliparea(SYMA_BEDROCK,thT("area bedrock",layout->lang));  
   
   // vodne toky (ciary, body)
 #define legend_waterflow(mid,txt) \
